summaryrefslogtreecommitdiff
path: root/png.h
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2014-12-18 08:41:59 -0600
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2014-12-18 08:51:00 -0600
commitb0c2c4154a4d4a6160dcd6400d2491a008f5d3bc (patch)
tree47fffebea235955d9f1f6e65902a70c3bb009b02 /png.h
parent8eb6549daced9aa941230800338294931d7ca6d9 (diff)
downloadlibpng-b0c2c4154a4d4a6160dcd6400d2491a008f5d3bc.tar.gz
[libpng15] Bump version to 1.5.21beta02
Diffstat (limited to 'png.h')
-rw-r--r--png.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/png.h b/png.h
index e911c90b9..dda7e24b7 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.5.21beta01 - December 15, 2014
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.5.21beta01 - December 15, 2014: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -202,7 +202,7 @@
* 1.5.20beta01-02 15 10520 15.so.15.20[.0]
* 1.5.20rc01-03 15 10520 15.so.15.20[.0]
* 1.5.20 15 10520 15.so.15.20[.0]
- * 1.5.21beta01 15 10521 15.so.15.21[.0]
+ * 1.5.21beta01-02 15 10521 15.so.15.21[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -234,7 +234,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.5.21beta01, December 15, 2014, are
* Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -346,13 +346,13 @@
* Y2K compliance in libpng:
* =========================
*
- * December 15, 2014
+ * December 18, 2014
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.5.21beta01 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*
* Libpng only has two year fields. One is a 2-byte unsigned integer
@@ -413,9 +413,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.5.21beta01"
+#define PNG_LIBPNG_VER_STRING "1.5.21beta02"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.5.21beta01 - December 15, 2014\n"
+ " libpng version 1.5.21beta02 - December 18, 2014\n"
#define PNG_LIBPNG_VER_SONUM 15
#define PNG_LIBPNG_VER_DLLNUM 15
@@ -429,7 +429,7 @@
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 01
+#define PNG_LIBPNG_VER_BUILD 02
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -576,7 +576,7 @@ extern "C" {
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef char* png_libpng_version_1_5_21beta01;
+typedef char* png_libpng_version_1_5_21beta02;
/* Three color definitions. The order of the red, green, and blue, (and the
* exact size) is not important, although the size of the fields need to
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.5.21beta01 - December 15, 2014
+ * libpng version 1.5.21beta02 - December 18, 2014
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.5.21beta01 - December 15, 2014: Glenn
+ * libpng versions 0.97, January 1998, through 1.5.21beta02 - December 18, 2014: Glenn
* See also "Contributing Authors", below.
*
@@ -234,7 +234,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.5.21beta01, December 15, 2014, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.21beta02, December 18, 2014, are
* Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -346,13 +346,13 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.5.21beta01 are Y2K compliant. It is my belief that
+ * upward through 1.5.21beta02 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*